@@ -90,7 +90,7 @@ static MagnifierOptions global_options = { ":0.0",
 					   10,
 					   10,
 					   0,
-					   0,
+					   1,
 					   0,
 					   0,
 					   0
@@ -306,15 +306,17 @@ magnifier_main_refresh_all (gpointer data)
 	regions = GNOME_Magnifier_Magnifier_getZoomRegions (
 		BONOBO_OBJREF (magnifier),
 		&ev);
-#ifdef DEBUG
+
+#ifdef DEBUG_REFRESH
 	fprintf (stderr, "refreshing %d regions\n", regions->_length);
 #endif
+#undef DEBUG_REFRESH
 
 	properties = GNOME_Magnifier_Magnifier_getProperties (BONOBO_OBJREF (magnifier), &ev);
 
-	dirty_bounds_any = Bonobo_PropertyBag_getValue (properties, "source-display-size", &ev);
+	dirty_bounds_any = Bonobo_PropertyBag_getValue (properties, "source-display-bounds", &ev);
 	if (BONOBO_EX (&ev)) {
-		g_warning ("Error getting source-display-size");
+		g_warning ("Error getting source-display-bounds");
 		bonobo_main_quit ();
 		return FALSE;
 	}
@@ -340,7 +342,7 @@ main (int argc, char** argv)
   GNOME_Magnifier_RectBounds *roi = GNOME_Magnifier_RectBounds__alloc();
   GNOME_Magnifier_RectBounds *viewport = GNOME_Magnifier_RectBounds__alloc();
   CORBA_any *viewport_any;
-  int x = 0, y = 0;
+  int x = 0, y = 0, fullwidth, fullheight;
   guint pan_handle = 0, refresh_handle = 0;
   CORBA_Environment ev;
   Bonobo_PropertyBag properties;
@@ -412,10 +414,10 @@ main (int argc, char** argv)
 				     global_options.cursor_color, 
 				     NULL);
 
-  screen_width = gdk_screen_get_width (
+  fullwidth = screen_width = gdk_screen_get_width (
 	  gdk_display_get_screen (magnifier->target_display,
 				  magnifier->target_screen_num));
-  screen_height = gdk_screen_get_height (
+  fullheight = screen_height = gdk_screen_get_height (
 	  gdk_display_get_screen (magnifier->target_display,
 				  magnifier->target_screen_num));
 
@@ -430,15 +432,24 @@ main (int argc, char** argv)
   fprintf (stderr, "initial viewport %d %d\n", (int) screen_width,
 	   (int) screen_height);
 
-  viewport_any = CORBA_any__alloc ();
   init_rect_bounds (viewport, x, y, x + screen_width, y + screen_height);
-  viewport_any->_type = TC_GNOME_Magnifier_RectBounds;
-  viewport_any->_value = ORBit_copy_value (viewport,
-					   TC_GNOME_Magnifier_RectBounds);
+  viewport_any = bonobo_arg_new_from (TC_GNOME_Magnifier_RectBounds, viewport);
   
-  Bonobo_PropertyBag_setValue (properties, "target-display-bounds",
-			       viewport_any,
-			       &ev);
+  bonobo_pbclient_set_value (properties, "target-display-bounds",
+			     viewport_any,
+			     &ev);
+  bonobo_arg_release (viewport_any);
+
+  if (global_options.vertical_split || global_options.horizontal_split) 
+  {
+      init_rect_bounds (viewport, 0, 0, fullwidth-x, fullheight-y);
+      viewport_any = bonobo_arg_new_from (TC_GNOME_Magnifier_RectBounds, viewport);
+      bonobo_pbclient_set_value (properties, "source-display-bounds",
+				 viewport_any,
+				 &ev);
+
+      bonobo_arg_release (viewport_any);
+  }
 
   bonobo_object_release_unref (properties, NULL);
   properties = NULL;
@@ -475,12 +486,13 @@ main (int argc, char** argv)
 				       global_options.timing_output, &ev);
 	  bonobo_pbclient_set_long (properties, "timing-pan-rate",
 				       global_options.timing_pan_rate, &ev);
-	  bonobo_pbclient_set_boolean (properties, "smooth-scroll-policy",
-				       scroll_policy, &ev);
-	  bonobo_pbclient_set_long    (properties, "border_size",
+	  g_message ("setting zoom properties border-size to %d\n", global_options.border_width);
+	  bonobo_pbclient_set_long    (properties, "border-size",
 				       global_options.border_width, &ev);
 	  bonobo_pbclient_set_long    (properties, "border-color",
 				       global_options.border_color, &ev);
+	  bonobo_pbclient_set_short   (properties, "smooth-scroll-policy",
+				       (short) scroll_policy, &ev);
 	  bonobo_pbclient_set_boolean (properties, "use-test-pattern",
 				       global_options.test_pattern, &ev);
 
